==> hometodos_0.9.5-1.tar.gz: hometodos-0.9.5/hometodos.py <==
import gtk
import hildondesktop
import cairo
import gobject
import pango
import commands
import traceback
import re
import datetime
import sys
import socket
import fcntl
import string
from ConfigParser import *
import mtodos_framework

supports_alpha = False

class TodosPlugin(hildondesktop.HomeItem):
  def __init__(self):
    hildondesktop.HomeItem.__init__(self)

    if(int(self._prefRead('autosize'))==1):
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
    else:
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)

    self.connect("settings", self._DoSettings)

    self.label = gtk.Label()
    self.label.set_use_markup(True)
    self.label.modify_font(pango.FontDescription (self._prefRead('font')))
    self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('background')))
    self.label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('foreground')))
    self.label.set_markup(self.get_text())
    self.label.set_padding(15, 10)
#   self.label.set_padding(-1, -1)
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    self.inbackground = False

    self.connect("expose-event", self.expose)
    self.connect("screen-changed", self.screen_changed)
    self.add(self.label)
    self.show_all()

    # set a timeout to change the images
    self.timer = gobject.timeout_add(120000, self.update)
#   print "foreground timer", self.timer

    self.connect ("background", self.background)
    self.connect ("foreground", self.foreground)

  def _DoSettings(self,widget,data=None):
    menuitem = gtk.MenuItem("HomeTodos")
    menuitem.connect_object("activate", self._ShowSettings,None)
    return menuitem

  def _color_to_string(self,c):
    t = "#"

    if len(hex(c.red)[2:4])==1:
      t = t+'0'+hex(c.red)[2:4]
    else:
      t = t+hex(c.red)[2:4]
    if len(hex(c.green)[2:4])==1:
      t = t+'0'+hex(c.green)[2:4]
    else:
      t = t+hex(c.green)[2:4]
    if len(hex(c.blue)[2:4])==1:
      t = t+'0'+hex(c.blue)[2:4]
    else:
      t = t+hex(c.blue)[2:4]
    return t

  def _validate(self,widget,*data):
#   print self._widgetTree.get_widget("color_background").get_current_color()
    self._prefSave('background',self._color_to_string(self._widgetTree.get_widget("color_background").get_current_color()))
    self._prefSave('foreground',self._color_to_string(self._widgetTree.get_widget("color_foreground").get_current_color()))
    self._prefSave('title',self._color_to_string(self._widgetTree.get_widget("color_title").get_current_color()))
    self._prefSave('background_alpha',str(self._widgetTree.get_widget("color_background").get_current_alpha()))
    self._prefSave('foreground_alpha',str(self._widgetTree.get_widget("color_foreground").get_current_alpha()))
    self._prefSave('title_alpha',str(self._widgetTree.get_widget("color_title").get_current_alpha()))
    self._prefSave('font',self._widgetTree.get_widget("fontselection").get_font_name())
    self._prefSave('autosize',str(int(self._widgetTree.get_widget("bautosize").get_active())))
    self._window.destroy()

  def _cancel(self,widget,*data):
    self._window.destroy()

  def _closebox(self,widget,*data):
    self._window.destroy()

  def _prefRead(self,key):
    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
    c = ConfigParser(default)
    c.read('/home/user/.hometodos')
#   print key+':'+str(c.get("DEFAULT", key))
    return c.get("DEFAULT", key)

  def _prefSave(self,key,value):
#   print str(key) + ':' + str(value)
    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
    c = ConfigParser(default)
    c.read('/home/user/.hometodos')
    c.set('DEFAULT',key,value)
    fp = open('/home/user/.hometodos','w')
    c.write(fp)
    fp.close()

  def _ShowSettings(self,widget,data=None):
    import gtk.glade
    self._widgetTree = gtk.glade.XML('/usr/lib/hometodos/prefs.glade')
    self._window = self._widgetTree.get_widget("prefs")
    self._widgetTree.get_widget("color_background").set_current_color(gtk.gdk.color_parse(self._prefRead('background')))
    self._widgetTree.get_widget("color_background").set_has_opacity_control(True)
    self._widgetTree.get_widget("color_background").set_current_alpha(int(self._prefRead('background_alpha')))
    self._widgetTree.get_widget("color_foreground").set_current_color(gtk.gdk.color_parse(self._prefRead('foreground')))
    self._widgetTree.get_widget("color_foreground").set_current_alpha(int(self._prefRead('foreground_alpha')))
    self._widgetTree.get_widget("color_foreground").set_has_opacity_control(True)
    self._widgetTree.get_widget("color_title").set_current_color(gtk.gdk.color_parse(self._prefRead('title')))
    self._widgetTree.get_widget("color_title").set_current_alpha(int(self._prefRead('title_alpha')))
    self._widgetTree.get_widget("color_title").set_has_opacity_control(True)
    self._widgetTree.get_widget("fontselection").set_font_name(self._prefRead('font'))
    self._widgetTree.get_widget("bautosize").set_active(int(self._prefRead('autosize')))

    callbackMapping = {
      # Signal
      "on_bCancel_clicked": self._cancel,
      "on_bValidate_clicked": self._validate,
    }
    self._widgetTree.signal_autoconnect(callbackMapping)
    self._window.connect("delete-event", self._closebox)

    self._window.show()

    return True

  def expose(self, widget, event):
    cr = self.window.cairo_create()
    if supports_alpha == True:
      cr.set_source_rgba(1.0, 1.0, 1.0, 0.0) # Transparent
    else:
      cr.set_source_rgb(1.0, 1.0, 1.0) # Opaque white

    # Draw the background
    cr.set_operator(cairo.OPERATOR_SOURCE)
    cr.paint()

    # draw rounded rect
    width, height = self.allocation[2], self.allocation[3]

    #/* a custom shape, that could be wrapped in a function */
    x0 = 0   #/*< parameters like cairo_rectangle */
    y0 = 0

    radius = min(15, width/2, height/2)  #/*< and an approximate curvature radius */

    x1 = x0 + width
    y1 = y0 + height

    cr.move_to  (x0, y0 + radius)
    cr.arc (x0 + radius, y0 + radius, radius, 3.14, 1.5 * 3.14)
    cr.line_to (x1 - radius, y0)
    cr.arc (x1 - radius, y0 + radius, radius, 1.5 * 3.14, 0.0)
    cr.line_to (x1 , y1 - radius)
    cr.arc (x1 - radius, y1 - radius, radius, 0.0, 0.5 * 3.14)
    cr.line_to (x0 + radius, y1)
    cr.arc (x0 + radius, y1 - radius, radius, 0.5 * 3.14, 3.14)

    cr.close_path ()

    bg_color=gtk.gdk.color_parse(self._prefRead('background'))

    cr.set_source_rgba (bg_color.red / 65535.0, bg_color.green/65535.0, bg_color.blue/65535.0, float(self._prefRead('background_alpha'))/65535.0)
    cr.fill_preserve ()

  def screen_changed(self, widget, old_screen=None):
    global supports_alpha

    # To check if the display supports alpha channels, get the colormap
    screen = widget.get_screen()
    colormap = screen.get_rgba_colormap()
    if colormap == None:
#     print 'Your screen does not support alpha channels!'
      colormap = screen.get_rgb_colormap()
      supports_alpha = False
    else:
#     print 'Your screen supports alpha channels!'
      supports_alpha = True

    # Now we have a colormap appropriate for the screen, use it
    widget.set_colormap(colormap)

    return False

  def update(self):
    self.label.set_markup(self.get_text())
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    return not self.inbackground

  def background(self, widget, data=None):
    #Avoid refresh when applet is in background
    #self.label.set_text("refreshing")
    #self.label.set_size_request(-1,-1)
    #self.set_size_request(-1,-1)
    self.inbackground = True
    if self.timer != None:
      gobject.source_remove(self.timer)
      self.timer = None

  def foreground(self, widget, data=None):
    if(int(self._prefRead('autosize'))==1):
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
    else:
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)

    self.label.modify_font(pango.FontDescription (self._prefRead('font')))
    self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('background')))
    self.label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('foreground')))
    self.label.set_markup(self.get_text())
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    self.inbackground = False
    self.timer = gobject.timeout_add(6000, self.update)

  def unrealize(self, widget, date=None):
    v = gobject.source_remove(self.timer)

  def get_cpu(self):
    text = ""
#    text = text + 'Loadavg: ' + commands.getoutput("awk '{print $1 \" \" $2 \" \" $3}' /proc/loadavg")
    loadavg = open("/proc/loadavg").readlines()
    for line in loadavg:
      load = line.split()
    text = text + 'Loadavg: ' + load[0] + " " + load[1] + " " + load[2]
    return text

  def get_mem(self):
    text = ""
#    devs = commands.getoutput("awk '$1 ~ /MemFree/ {print $2}' /proc/meminfo")
#    memfree = int(devs)
#    devs = commands.getoutput("awk '$1 ~ /^Cached/ {print $2}' /proc/meminfo")
#    memcached = int(devs)
#    text = 'Free Mem: '+(memfree+memcached).__str__() + ' kB'
#    devs = commands.getoutput("awk '$1 ~ /SwapFree/ {print $2}' /proc/meminfo")
#    swap = int(devs)
#    text = text + '\nFree Swap: '+(swap).__str__() + ' kB'
    meminfo = open("/proc/meminfo").readlines()
    for line in meminfo:
      if line[:7] == "MemFree":
        tmp = line.split()
        memfree = int(tmp[1])
      elif line[:6] == "Cached":
        tmp = line.split()
        memcached = int(tmp[1])
      elif line[:8] == "SwapFree":
        tmp = line.split()
        swapfree = int(tmp[1])
    text = 'Free Mem: '+ (memfree + memcached).__str__() + ' kB'
    text = text + '\nFree Swap: '+ (swapfree).__str__() + ' kB'
    return text

  def get_top(self):
    text = ""
    devs = commands.getoutput("top -n1 | head -8 | awk '{print $8 \" \" $7 \" \" $6}'")
    sdevs = devs.rsplit('\n')
    i=0
    for stdev in sdevs:
      if i>2:
        text = text + stdev + '\n'
      i=i+1
    return text

  def read_ip(self, ifname):
    SIOCGIFADDR = 0x8915
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    ifr = ifname + '\0' * (16 - len(ifname)) + chr(socket.AF_INET) + 15 * '\0'
    try:
      r = fcntl.ioctl(s.fileno(), SIOCGIFADDR, ifr)
    except IOError:
      return None
    addr = string.join(map(str, map(ord, r[20:24])), '.')
    return addr

  def get_ip(self):
    text = "No IP"
#    devs = commands.getoutput("/sbin/ifconfig wlan0")
#    sdevs = devs.rsplit('\n')
#    for stdev in sdevs:
#      if 'inet addr:' in stdev:
#        sdev = stdev.rsplit(':')
#        sdev2 = sdev[1].rsplit(' ')
#        text= "IP: " + sdev2[0]
    wireless = None

    wlan0 = self.read_ip("wlan0")
    if wlan0:
      text = "IP: " + wlan0
      wireless = open("/proc/net/wireless").readlines()

    if text == "No IP":
#      devs = commands.getoutput("/sbin/ifconfig ppp0")
#      sdevs = devs.rsplit('\n')
#      for stdev in sdevs:
#        if 'inet addr:' in stdev:
#          sdev = stdev.rsplit(':')
#          sdev2 = sdev[1].rsplit(' ')
#          text= "IP: " + sdev2[0]
      ppp0 = self.read_ip("ppp0")
      if ppp0:
        text = "IP: " + ppp0

    signal = "0"
    if wireless:
      for line in wireless:
        if line[:6] == " wlan0":
          tmp = line.split()
          signal = tmp[2].rstrip('.')
    text = text + '\nWifi Signal: ' + signal + '%'

#    devs = commands.getoutput("awk '{print $3}' /proc/net/wireless")
#    sdev = devs.rsplit('\n')
#    text = text + '\nWifi Signal: ' + sdev[2].rstrip('.') + ' %'
    return text

  def get_now(self):
    #Get Now Todos
    todos_uuid_list =  mtodos_framework.TodosList().get_now_todos()
    text = ""
    todos_uuid_list.sort()
    todo = None
    for (todo_status,todo_due_datetime,todo_uuid) in todos_uuid_list:
      todo = mtodos_framework.Todo(todo_uuid)
      text = text + '\n' + todo.description
    return text

  def get_next(self):
    #Get Now Todos
    todos_uuid_list =  mtodos_framework.TodosList().get_next_todos()
    text = ""
    todos_uuid_list.sort()
    todo = None
    for (todo_status,todo_due_datetime,todo_uuid) in todos_uuid_list:
      todo = mtodos_framework.Todo(todo_uuid)
      text = text + '\n' + todo.description
    return text

  def get_text(self):
    now = '<span foreground="'+self._prefRead('title')+'">Now</span>\n'+self.get_now()
    next = '<span foreground="'+self._prefRead('title')+'">Next</span>\n'+self.get_next()
    text = now + '\n\n'+next + '\n'
    return text

def hd_plugin_get_objects():
  plugin = TodosPlugin()
  return [plugin]

if __name__ == "__main__":
  print TodosPlugin()
  print TodosPlugin().get_text()
  gtk.main()

==> hometodos_0.9.7-1.tar.gz: hometodos-0.9.7/hometodos.py <==
import gtk
import hildondesktop
import cairo
import gobject
import pango
import commands
import traceback
import re
import datetime
import sys
import socket
import fcntl
import string
from ConfigParser import *
import mtodos_framework

supports_alpha = False

class TodosPlugin(hildondesktop.HomeItem):
  def __init__(self):
    hildondesktop.HomeItem.__init__(self)

    if(int(self._prefRead('autosize'))==1):
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
    else:
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)

    self.connect("settings", self._DoSettings)

    self.label = gtk.Label()
    self.label.set_use_markup(True)
    self.label.modify_font(pango.FontDescription (self._prefRead('font')))
    self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('background')))
    self.label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('foreground')))
    self.label.set_markup(self.get_text())
    self.label.set_padding(15, 10)
#   self.label.set_padding(-1, -1)
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    self.inbackground = False

    self.connect("expose-event", self.expose)
    self.connect("screen-changed", self.screen_changed)
    self.add(self.label)
    self.show_all()

    # set a timeout to change the images
    self.timer = gobject.timeout_add(120000, self.update)
#   print "foreground timer", self.timer

    self.connect ("background", self.background)
    self.connect ("foreground", self.foreground)

  def _DoSettings(self,widget,data=None):
    menuitem = gtk.MenuItem("HomeTodos")
    menuitem.connect_object("activate", self._ShowSettings,None)
    return menuitem

  def _color_to_string(self,c):
    t = "#"

    if len(hex(c.red)[2:4])==1:
      t = t+'0'+hex(c.red)[2:4]
    else:
      t = t+hex(c.red)[2:4]
    if len(hex(c.green)[2:4])==1:
      t = t+'0'+hex(c.green)[2:4]
    else:
      t = t+hex(c.green)[2:4]
    if len(hex(c.blue)[2:4])==1:
      t = t+'0'+hex(c.blue)[2:4]
    else:
      t = t+hex(c.blue)[2:4]
    return t

  def _validate(self,widget,*data):
#   print self._widgetTree.get_widget("color_background").get_current_color()
    self._prefSave('background',self._color_to_string(self._widgetTree.get_widget("color_background").get_current_color()))
    self._prefSave('foreground',self._color_to_string(self._widgetTree.get_widget("color_foreground").get_current_color()))
    self._prefSave('title',self._color_to_string(self._widgetTree.get_widget("color_title").get_current_color()))
    self._prefSave('background_alpha',str(self._widgetTree.get_widget("color_background").get_current_alpha()))
    self._prefSave('foreground_alpha',str(self._widgetTree.get_widget("color_foreground").get_current_alpha()))
    self._prefSave('title_alpha',str(self._widgetTree.get_widget("color_title").get_current_alpha()))
    self._prefSave('font',self._widgetTree.get_widget("fontselection").get_font_name())
    self._prefSave('autosize',str(int(self._widgetTree.get_widget("bautosize").get_active())))
    self._window.destroy()

  def _cancel(self,widget,*data):
    self._window.destroy()

  def _closebox(self,widget,*data):
    self._window.destroy()

  def _prefRead(self,key):
    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
    c = ConfigParser(default)
    c.read('/home/user/.hometodos')
#   print key+':'+str(c.get("DEFAULT", key))
    return c.get("DEFAULT", key)

  def _prefSave(self,key,value):
#   print str(key) + ':' + str(value)
    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
    c = ConfigParser(default)
    c.read('/home/user/.hometodos')
    c.set('DEFAULT',key,value)
    fp = open('/home/user/.hometodos','w')
    c.write(fp)
    fp.close()

  def _ShowSettings(self,widget,data=None):
    import gtk.glade
    self._widgetTree = gtk.glade.XML('/usr/lib/hometodos/prefs.glade')
    self._window = self._widgetTree.get_widget("prefs")
    self._widgetTree.get_widget("color_background").set_current_color(gtk.gdk.color_parse(self._prefRead('background')))
    self._widgetTree.get_widget("color_background").set_has_opacity_control(True)
    self._widgetTree.get_widget("color_background").set_current_alpha(int(self._prefRead('background_alpha')))
    self._widgetTree.get_widget("color_foreground").set_current_color(gtk.gdk.color_parse(self._prefRead('foreground')))
    self._widgetTree.get_widget("color_foreground").set_current_alpha(int(self._prefRead('foreground_alpha')))
    self._widgetTree.get_widget("color_foreground").set_has_opacity_control(True)
    self._widgetTree.get_widget("color_title").set_current_color(gtk.gdk.color_parse(self._prefRead('title')))
    self._widgetTree.get_widget("color_title").set_current_alpha(int(self._prefRead('title_alpha')))
    self._widgetTree.get_widget("color_title").set_has_opacity_control(True)
    self._widgetTree.get_widget("fontselection").set_font_name(self._prefRead('font'))
    self._widgetTree.get_widget("bautosize").set_active(int(self._prefRead('autosize')))

    callbackMapping = {
      # Signal
      "on_bCancel_clicked": self._cancel,
      "on_bValidate_clicked": self._validate,
    }
    self._widgetTree.signal_autoconnect(callbackMapping)
    self._window.connect("delete-event", self._closebox)

    self._window.show()

    return True

  def expose(self, widget, event):
    cr = self.window.cairo_create()
    if supports_alpha == True:
      cr.set_source_rgba(1.0, 1.0, 1.0, 0.0) # Transparent
    else:
      cr.set_source_rgb(1.0, 1.0, 1.0) # Opaque white

    # Draw the background
    cr.set_operator(cairo.OPERATOR_SOURCE)
    cr.paint()

    # draw rounded rect
    width, height = self.allocation[2], self.allocation[3]

    #/* a custom shape, that could be wrapped in a function */
    x0 = 0   #/*< parameters like cairo_rectangle */
    y0 = 0

    radius = min(15, width/2, height/2)  #/*< and an approximate curvature radius */

    x1 = x0 + width
    y1 = y0 + height

    cr.move_to  (x0, y0 + radius)
    cr.arc (x0 + radius, y0 + radius, radius, 3.14, 1.5 * 3.14)
    cr.line_to (x1 - radius, y0)
    cr.arc (x1 - radius, y0 + radius, radius, 1.5 * 3.14, 0.0)
    cr.line_to (x1 , y1 - radius)
    cr.arc (x1 - radius, y1 - radius, radius, 0.0, 0.5 * 3.14)
    cr.line_to (x0 + radius, y1)
    cr.arc (x0 + radius, y1 - radius, radius, 0.5 * 3.14, 3.14)

    cr.close_path ()

    bg_color=gtk.gdk.color_parse(self._prefRead('background'))

    cr.set_source_rgba (bg_color.red / 65535.0, bg_color.green/65535.0, bg_color.blue/65535.0, float(self._prefRead('background_alpha'))/65535.0)
    cr.fill_preserve ()

  def screen_changed(self, widget, old_screen=None):
    global supports_alpha

    # To check if the display supports alpha channels, get the colormap
    screen = widget.get_screen()
    colormap = screen.get_rgba_colormap()
    if colormap == None:
#     print 'Your screen does not support alpha channels!'
      colormap = screen.get_rgb_colormap()
      supports_alpha = False
    else:
#     print 'Your screen supports alpha channels!'
      supports_alpha = True

    # Now we have a colormap appropriate for the screen, use it
    widget.set_colormap(colormap)

    return False

  def update(self):
    self.label.set_markup(self.get_text())
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    return not self.inbackground

  def background(self, widget, data=None):
    #Avoid refresh when applet is in background
    #self.label.set_text("refreshing")
    #self.label.set_size_request(-1,-1)
    #self.set_size_request(-1,-1)
    self.inbackground = True
    if self.timer != None:
      gobject.source_remove(self.timer)
      self.timer = None

  def foreground(self, widget, data=None):
    if(int(self._prefRead('autosize'))==1):
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
    else:
      self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)

    self.label.modify_font(pango.FontDescription (self._prefRead('font')))
    self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('background')))
    self.label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('foreground')))
    self.label.set_markup(self.get_text())
    self.label.set_size_request(-1,-1)
    self.set_size_request(-1,-1)
    self.inbackground = False
    self.timer = gobject.timeout_add(6000, self.update)

  def unrealize(self, widget, date=None):
    v = gobject.source_remove(self.timer)

  def get_cpu(self):
    text = ""
#    text = text + 'Loadavg: ' + commands.getoutput("awk '{print $1 \" \" $2 \" \" $3}' /proc/loadavg")
    loadavg = open("/proc/loadavg").readlines()
    for line in loadavg:
      load = line.split()
    text = text + 'Loadavg: ' + load[0] + " " + load[1] + " " + load[2]
    return text

  def get_mem(self):
    text = ""
#    devs = commands.getoutput("awk '$1 ~ /MemFree/ {print $2}' /proc/meminfo")
#    memfree = int(devs)
#    devs = commands.getoutput("awk '$1 ~ /^Cached/ {print $2}' /proc/meminfo")
#    memcached = int(devs)
#    text = 'Free Mem: '+(memfree+memcached).__str__() + ' kB'
#    devs = commands.getoutput("awk '$1 ~ /SwapFree/ {print $2}' /proc/meminfo")
#    swap = int(devs)
#    text = text + '\nFree Swap: '+(swap).__str__() + ' kB'
    meminfo = open("/proc/meminfo").readlines()
    for line in meminfo:
      if line[:7] == "MemFree":
        tmp = line.split()
        memfree = int(tmp[1])
      elif line[:6] == "Cached":
        tmp = line.split()
        memcached = int(tmp[1])
      elif line[:8] == "SwapFree":
        tmp = line.split()
        swapfree = int(tmp[1])
    text = 'Free Mem: '+ (memfree + memcached).__str__() + ' kB'
    text = text + '\nFree Swap: '+ (swapfree).__str__() + ' kB'
    return text

  def get_top(self):
    text = ""
    devs = commands.getoutput("top -n1 | head -8 | awk '{print $8 \" \" $7 \" \" $6}'")
    sdevs = devs.rsplit('\n')
    i=0
    for stdev in sdevs:
      if i>2:
        text = text + stdev + '\n'
      i=i+1
    return text

  def read_ip(self, ifname):
    SIOCGIFADDR = 0x8915
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    ifr = ifname + '\0' * (16 - len(ifname)) + chr(socket.AF_INET) + 15 * '\0'
    try:
      r = fcntl.ioctl(s.fileno(), SIOCGIFADDR, ifr)
    except IOError:
      return None
    addr = string.join(map(str, map(ord, r[20:24])), '.')
    return addr

  def get_ip(self):
    text = "No IP"
#    devs = commands.getoutput("/sbin/ifconfig wlan0")
#    sdevs = devs.rsplit('\n')
#    for stdev in sdevs:
#      if 'inet addr:' in stdev:
#        sdev = stdev.rsplit(':')
#        sdev2 = sdev[1].rsplit(' ')
#        text= "IP: " + sdev2[0]
    wireless = None

    wlan0 = self.read_ip("wlan0")
    if wlan0:
      text = "IP: " + wlan0
      wireless = open("/proc/net/wireless").readlines()

    if text == "No IP":
#      devs = commands.getoutput("/sbin/ifconfig ppp0")
#      sdevs = devs.rsplit('\n')
#      for stdev in sdevs:
#        if 'inet addr:' in stdev:
#          sdev = stdev.rsplit(':')
#          sdev2 = sdev[1].rsplit(' ')
#          text= "IP: " + sdev2[0]
      ppp0 = self.read_ip("ppp0")
      if ppp0:
        text = "IP: " + ppp0

    signal = "0"
    if wireless:
      for line in wireless:
        if line[:6] == " wlan0":
          tmp = line.split()
          signal = tmp[2].rstrip('.')
    text = text + '\nWifi Signal: ' + signal + '%'

#    devs = commands.getoutput("awk '{print $3}' /proc/net/wireless")
#    sdev = devs.rsplit('\n')
#    text = text + '\nWifi Signal: ' + sdev[2].rstrip('.') + ' %'
    return text

  def get_now(self):
    #Get Now Todos
    todos_uuid_list =  mtodos_framework.TodosList().get_now_todos()
    text = ""
    todos_uuid_list.sort()
    todo = None
    for (todo_status,todo_due_datetime,todo_uuid) in todos_uuid_list:
      todo = mtodos_framework.Todo(todo_uuid)
      text = text + '\n' + todo.description
    return text

  def get_next(self):
    #Get Now Todos
    todos_uuid_list =  mtodos_framework.TodosList().get_next_todos()
    text = ""
    todos_uuid_list.sort()
    todo = None
    for (todo_status,todo_due_datetime,todo_uuid) in todos_uuid_list:
      todo = mtodos_framework.Todo(todo_uuid)
      text = text + '\n' + todo.description
    return text

  def get_text(self):
    now = self.get_now()
    if now == "":
      now = 'Nothing'
    now = '<span foreground="'+self._prefRead('title')+'">Now</span>\n'+now
    next = self.get_next()
    if next == "":
      next = 'Nothing'
    next = '<span foreground="'+self._prefRead('title')+'">Next</span>\n'+next
    text = now + '\n\n'+next + '\n'
    return text

def hd_plugin_get_objects():
  plugin = TodosPlugin()
  return [plugin]

if __name__ == "__main__":
  print TodosPlugin()
  print TodosPlugin().get_text()
  gtk.main()
